package com.caimei.controller.user;

import com.caimei.entity.*;
import com.caimei.service.user.PersonalService;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;
import java.util.Map;

/**
 * 个人中心
 */
@Controller
@RequestMapping("/personal")
public class PersonalController {
    @Autowired
    private PersonalService personalService;

    /**
     * 我的个人显示数据
     *
     * @param operationUser
     * @return
     */
    @RequestMapping("/myCentre")
    @ResponseBody
    public WxJsonModel myCentre(CmOperationUser operationUser) {
        WxJsonModel res = WxJsonModel.newInstance();
        Club club = personalService.myCentre(operationUser);
        return res.success("1", club);
    }

    /**
     * 账户余额明细
     *
     * @return
     */
    @ResponseBody
    @RequestMapping("/touchBalance")
    public Map<String, Object> touchBalance(int year, int month, Integer index, Integer pageSize, CmUserBalanceRecord balanceRecord) {
        Map<String, Object> map = personalService.touchBalance(index, pageSize, year, month, balanceRecord);
        return map;
    }

    /**
     * 地址管理:省市区
     */
    @ResponseBody
    @RequestMapping("/address")
    public List<Province> address() {
        List<Province> list = personalService.address();
        return list;
    }

    /**
     * 省
     */
    @ResponseBody
    @RequestMapping("/province")
    public List<Province> getProvince() {
        List<Province> provinceList = personalService.getProvince();
        return provinceList;
    }

    /**
     * 市
     */
    @ResponseBody
    @RequestMapping("/city")
    public List<City> getCity(Long provinceid) {
        List<City> cityList = personalService.getCity(provinceid);
        return cityList;
    }

    /**
     * 区
     */
    @ResponseBody
    @RequestMapping("/town")
    public List<Town> getTown(Integer cityid) {
        List<Town> townList = personalService.getTown(cityid);
        return townList;
    }

    /**
     * 查询用户所有地址
     *
     * @param userID
     * @return
     */
    @ResponseBody
    @RequestMapping("/findAddress")
    public Page<Address> findAddress(Integer userID, Integer index, Integer pageSize) {
        if (index == null) index = 1;
        if (pageSize == null) pageSize = 10;
        PageHelper.startPage(index, pageSize);
        List<Address> addressList = personalService.findAddress(userID);
        Page<Address> page = new Page<>(addressList);
        return page;
    }

    /**
     * 保存或编辑地址
     *
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public WxJsonModel saveAddress(@RequestBody Address address) {
        WxJsonModel res = WxJsonModel.newInstance();
        if (address == null) return res.error("参数异常");
        try {
            personalService.saveAddress(address);
        } catch (Exception e) {
            return res.error("保存失败");
        }
        return res.success("保存成功", "");
    }

    /**
     * 删除地址
     */
    @ResponseBody
    @RequestMapping("/delete")
    public WxJsonModel deleteAddress(Integer addressID) {
        WxJsonModel res = WxJsonModel.newInstance();
        try {
            personalService.deleteAddress(addressID);
        } catch (Exception e) {
            return res.error("删除失败");
        }
        return res.success("删除成功", "");
    }

}
