package com.caimei.service.user.impl;

import com.caimei.entity.*;
import com.caimei.mapper.user.PersonalMapper;
import com.caimei.service.user.PersonalService;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class PersonalServiceImpl implements PersonalService {
    @Autowired
    private PersonalMapper personalMapper;

    @Override
    public Club myCentre(CmOperationUser operationUser) {
        return personalMapper.myCentre(operationUser);
    }

    @Override
    public Map<String, Object> touchBalance(Integer index, Integer pageSize, int year, int month, CmUserBalanceRecord balanceRecord) {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, month - 1);
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getMinimum(Calendar.DATE));
        String startTime = format.format(calendar.getTime()) + " 00:00:00";
        balanceRecord.setStartTime(startTime);
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getActualMaximum(Calendar.DATE));
        String endTime = format.format(calendar.getTime()) + " 23:59:59";
        balanceRecord.setEndTime(endTime);
        if (index == null) index = 1;
        if (pageSize == null) pageSize = 10;
        PageHelper.startPage(index, pageSize);
        List<CmUserBalanceRecord> list = personalMapper.touchBalance(balanceRecord);
        Page<CmUserBalanceRecord> page = new Page<>(list);
        Integer ableUserMoney = personalMapper.ableUserMoney(balanceRecord.getUserId());
        if (ableUserMoney == null) ableUserMoney = 0;
        Map<String, Object> map = new HashMap();
        map.put("page", page);
        map.put("ableUserMoney", ableUserMoney);
        return map;
    }

    @Override
    public List<Province> address() {
        List<Province> list = personalMapper.findAllProvince();
        for (Province province : list) {
            List<City> cityList = personalMapper.findAllCity(province.getProvinceid());
            province.setCitys(cityList);
            if (cityList != null && cityList.size() > 0) {
                for (City city : cityList) {
                    List<Town> townList = personalMapper.findAllTown(city.getCityid());
                    city.setTowns(townList);
                }
            }
        }
        return list;
    }

    @Override
    public List<Address> findAddress(Integer userID) {
        List<Address> addressList = personalMapper.findAddress(userID);
        for (Address address : addressList) {
            Address cantonal = personalMapper.findCantonal(address.getTownID());
            address.setProvince(cantonal.getProvince());
            address.setCity(cantonal.getCity());
            address.setTown(cantonal.getTown());
        }
        return addressList;
    }

    @Override
    public List<Province> getProvince() {
        List<Province> list = personalMapper.findAllProvince();
        return list;
    }

    @Override
    public List<City> getCity(Long provinceid) {
        return personalMapper.findAllCity(provinceid);
    }

    @Override
    public List<Town> getTown(Integer cityid) {
        return personalMapper.findAllTown(cityid);
    }

    @Override
    public void saveAddress(Address address) {
        if (address.getDefaultFlag() != null && address.getDefaultFlag().equals("1")) {
            Address addr = personalMapper.findDefaultAddress(address.getUserID());
            if (addr != null) {
                addr.setDefaultFlag("0");
                personalMapper.updateAddress(addr);
            }
        }
        if (address.getAddressID() == null) {
            personalMapper.saveAddress(address);
        } else {
            personalMapper.updateAddress(address);
        }
    }

    @Override
    public void deleteAddress(Integer addressID) {
        personalMapper.deleteAddress(addressID);
    }


}
